Who is someone
==============

PyPi: https://pypi.org/project/happyname/

สวัสดีจ้าาาา แพ็คนี้คือแพ็คเกจที่อธิบายข้อมูลเกี่ยวกับบุคคล

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install happyname

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from happyname import NameAI

   uncle = NameAI()
   uncle.show_name()
   uncle.show_youtube()
   uncle.about()
   uncle.show_art()
